*********
Changelog
*********


v3.0.0a1 (2019-08-04)
=====================

Initial release which extracts the Mopidy-Local extension from Mopidy core.

This is an alpha release because it depends on the pre-releases of Mopidy 3.0.
